# MaseterTherm Connect Module
[![](https://img.shields.io/github/license/shedc/python-masterthermconnect?style=for-the-badge)](LICENSE)
[![](https://img.shields.io/github/workflow/status/shedc/python-masterthermconnect/Python%20package?style=for-the-badge)](https://github.com/shedc/python-masterthermconnect/actions)

## Abount
This module provides the connection and conversion tools to the API for the MasterTherm Heatpump Products.
The project was mainly built for a Plugin to Home Assistant

## Installation
python -m pip install masterthermconnect

## Usage
To be Completed
